News
====

0.4.5
-----

*Release date: 06-Apr-2011*

* Setting proper permissions for directories


0.4.4
-----

*Release date: 06-Apr-2011*

* Added support for Django's FILE_UPLOAD_PERMISSIONS when copying media

0.4.3
-----

*Release date: 01-Apr-2011*

* Added support Dojo 1.6

0.4.2
-----

*Release date: 01-Apr-2011*

* Added support for STATIC_ROOT and STATIC_URL for destination for copying media


0.4.0a3
-------

*Release date: 28-Jan-2011*

* Added support for rendering less.js on the server side. Need to have less.js installed into node.js

0.4.0a1
-------

*Release date: 07-Sep-2010*

* Renamed the project to django-skylark
* Added support for html5
* Added support for less.js
* Upgraded to Dojo 1.5.0
